@@ -1,38 +1,23 @@
 use std::collections::HashMap;
 
+use laurier::highlight::highlight_matched_text;
 use ratatui::{
     buffer::Buffer,
     crossterm::event::{Event, KeyEvent},
     layout::{Constraint, Layout, Rect},
-    style::{Color, Stylize},
+    style::{Color, Style, Stylize},
     text::{Line, Span},
     widgets::{List, ListItem, StatefulWidget, Widget},
 };
 use tui_input::{backend::crossterm::EventHandler, Input};
 
 use crate::{
+    color::ColorTheme,
     config::UiListConfig,
     git::{Commit, CommitHash, Head, Ref},
     graph::GraphImageManager,
 };
 
-const SELECTED_BACKGROUND_COLOR: Color = Color::DarkGray;
-const SELECTED_FOREGROUND_COLOR: Color = Color::White;
-
-const REF_PAREN_COLOR: Color = Color::Yellow;
-const REF_BRANCH_COLOR: Color = Color::Green;
-const REF_REMOTE_BRANCH_COLOR: Color = Color::Red;
-const REF_TAG_COLOR: Color = Color::Yellow;
-const REF_STASH_COLOR: Color = Color::Magenta;
-const HEAD_COLOR: Color = Color::Cyan;
-
-const SUBJECT_COLOR: Color = Color::Reset;
-const NAME_COLOR: Color = Color::Cyan;
-const HASH_COLOR: Color = Color::Yellow;
-const DATE_COLOR: Color = Color::Magenta;
-const MATCH_FOREGROUND_COLOR: Color = Color::Black;
-const MATCH_BACKGROUND_COLOR: Color = Color::Yellow;
-
 const ELLIPSIS: &str = "...";
 
 #[derive(Debug)]
@@ -164,6 +149,21 @@ impl<'a> CommitListState<'a> {
         }
     }
 
+    pub fn select_parent(&mut self) {
+        if let Some(target_commit) = self.selected_commit_parent_hash().cloned() {
+            while target_commit.as_str() != self.selected_commit_hash().as_str() {
+                self.select_next();
+            }
+        }
+    }
+
+    pub fn selected_commit_parent_hash(&self) -> Option<&CommitHash> {
+        self.commits[self.current_selected_index()]
+            .commit
+            .parent_commit_hashes
+            .first()
+    }
+
     pub fn select_prev(&mut self) {
         if self.selected > 0 {
             self.selected -= 1;
@@ -468,11 +468,15 @@ impl<'a> CommitListState<'a> {
 
 pub struct CommitList<'a> {
     config: &'a UiListConfig,
+    color_theme: &'a ColorTheme,
 }
 
 impl<'a> CommitList<'a> {
-    pub fn new(config: &'a UiListConfig) -> Self {
-        Self { config }
+    pub fn new(config: &'a UiListConfig, color_theme: &'a ColorTheme) -> Self {
+        Self {
+            config,
+            color_theme,
+        }
     }
 }
 
@@ -591,7 +595,8 @@ impl CommitList<'_> {
                 buf[(area.left(), area.top() + i as u16)]
                     .set_symbol(state.encoded_image(commit_info));
 
-                for w in 1..area.width {
+                // width - 1 for right pad
+                for w in 1..area.width - 1 {
                     buf[(area.left() + w, area.top() + i as u16)].set_skip(true);
                 }
             });
@@ -613,7 +618,7 @@ impl CommitList<'_> {
         let items: Vec<ListItem> = self
             .rendering_commit_info_iter(state)
             .map(|(i, commit_info)| {
-                let mut spans = refs_spans(commit_info, state.head);
+                let mut spans = refs_spans(commit_info, state.head, self.color_theme);
                 let ref_spans_width: usize = spans.iter().map(|s| s.width()).sum();
                 let max_width = max_width.saturating_sub(ref_spans_width);
                 let commit = commit_info.commit;
@@ -625,29 +630,18 @@ impl CommitList<'_> {
                         commit.subject.to_string()
                     };
 
-                    let sub_spans = if let Some(SearchMatchPosition { start, end }) =
-                        state.search_matches[state.offset + i].subject
-                    {
-                        if truncate {
-                            let not_truncated_width = max_width - ELLIPSIS.len();
-                            if not_truncated_width < start {
-                                highlight_matched_text(
-                                    subject,
-                                    not_truncated_width,
-                                    end,
-                                    SUBJECT_COLOR,
-                                )
-                            } else if start <= not_truncated_width && not_truncated_width < end {
-                                highlight_matched_text(subject, start, max_width, SUBJECT_COLOR)
-                            } else {
-                                highlight_matched_text(subject, start, end, SUBJECT_COLOR)
-                            }
+                    let sub_spans =
+                        if let Some(pos) = state.search_matches[state.offset + i].subject {
+                            highlighted_spans(
+                                subject,
+                                pos,
+                                self.color_theme.list_subject_fg,
+                                self.color_theme,
+                                truncate,
+                            )
                         } else {
-                            highlight_matched_text(subject, start, end, SUBJECT_COLOR)
-                        }
-                    } else {
-                        vec![subject.into()]
-                    };
+                            vec![subject.into()]
+                        };
 
                     spans.extend(sub_spans)
                 }
@@ -671,23 +665,16 @@ impl CommitList<'_> {
                 } else {
                     commit.author_name.to_string()
                 };
-                let spans = if let Some(SearchMatchPosition { start, end }) =
-                    state.search_matches[state.offset + i].author_name
-                {
-                    if truncate {
-                        let not_truncated_width = max_width - ELLIPSIS.len();
-                        if not_truncated_width < start {
-                            highlight_matched_text(name, not_truncated_width, end, NAME_COLOR)
-                        } else if start <= not_truncated_width && not_truncated_width < end {
-                            highlight_matched_text(name, start, max_width, NAME_COLOR)
-                        } else {
-                            highlight_matched_text(name, start, end, NAME_COLOR)
-                        }
-                    } else {
-                        highlight_matched_text(name, start, end, NAME_COLOR)
-                    }
+                let spans = if let Some(pos) = state.search_matches[state.offset + i].author_name {
+                    highlighted_spans(
+                        name,
+                        pos,
+                        self.color_theme.list_name_fg,
+                        self.color_theme,
+                        truncate,
+                    )
                 } else {
-                    vec![name.fg(NAME_COLOR)]
+                    vec![name.fg(self.color_theme.list_name_fg)]
                 };
                 self.to_commit_list_item(i, spans, state)
             })
@@ -703,12 +690,16 @@ impl CommitList<'_> {
             .rendering_commit_iter(state)
             .map(|(i, commit)| {
                 let hash = commit.commit_hash.as_short_hash();
-                let spans = if let Some(SearchMatchPosition { start, end }) =
-                    state.search_matches[state.offset + i].commit_hash
-                {
-                    highlight_matched_text(hash, start, end, HASH_COLOR)
+                let spans = if let Some(pos) = state.search_matches[state.offset + i].commit_hash {
+                    highlighted_spans(
+                        hash,
+                        pos,
+                        self.color_theme.list_hash_fg,
+                        self.color_theme,
+                        false,
+                    )
                 } else {
-                    vec![hash.fg(HASH_COLOR)]
+                    vec![hash.fg(self.color_theme.list_hash_fg)]
                 };
                 self.to_commit_list_item(i, spans, state)
             })
@@ -730,7 +721,7 @@ impl CommitList<'_> {
                 } else {
                     date.format(&self.config.date_format).to_string()
                 };
-                self.to_commit_list_item(i, vec![date_str.fg(DATE_COLOR)], state)
+                self.to_commit_list_item(i, vec![date_str.fg(self.color_theme.list_date_fg)], state)
             })
             .collect();
         Widget::render(List::new(items), area, buf);
@@ -739,7 +730,7 @@ impl CommitList<'_> {
     fn rendering_commit_info_iter<'a>(
         &'a self,
         state: &'a CommitListState,
-    ) -> impl Iterator<Item = (usize, &'a CommitInfo)> {
+    ) -> impl Iterator<Item = (usize, &'a CommitInfo<'a>)> {
         state
             .commits
             .iter()
@@ -768,41 +759,52 @@ impl CommitList<'_> {
         let mut line = Line::from(spans);
         if i == state.selected {
             line = line
-                .bg(SELECTED_BACKGROUND_COLOR)
-                .fg(SELECTED_FOREGROUND_COLOR);
+                .bg(self.color_theme.list_selected_bg)
+                .fg(self.color_theme.list_selected_fg);
         }
         ListItem::new(line)
     }
 }
 
-fn refs_spans<'a>(commit_info: &'a CommitInfo, head: &'a Head) -> Vec<Span<'a>> {
+fn refs_spans<'a>(
+    commit_info: &'a CommitInfo,
+    head: &'a Head,
+    color_theme: &'a ColorTheme,
+) -> Vec<Span<'a>> {
     let refs = &commit_info.refs;
 
     if refs.len() == 1 {
         if let Ref::Stash { name, .. } = refs[0] {
-            return vec![Span::raw(name).fg(REF_STASH_COLOR).bold(), Span::raw(" ")];
+            return vec![
+                Span::raw(name).fg(color_theme.list_ref_stash_fg).bold(),
+                Span::raw(" "),
+            ];
         }
     }
 
     let ref_spans: Vec<Span> = refs
         .iter()
         .filter_map(|r| match r {
-            Ref::Branch { name, .. } => Some(Span::raw(name).fg(REF_BRANCH_COLOR).bold()),
-            Ref::RemoteBranch { name, .. } => {
-                Some(Span::raw(name).fg(REF_REMOTE_BRANCH_COLOR).bold())
+            Ref::Branch { name, .. } => {
+                Some(Span::raw(name).fg(color_theme.list_ref_branch_fg).bold())
             }
-            Ref::Tag { name, .. } => Some(Span::raw(name).fg(REF_TAG_COLOR).bold()),
+            Ref::RemoteBranch { name, .. } => Some(
+                Span::raw(name)
+                    .fg(color_theme.list_ref_remote_branch_fg)
+                    .bold(),
+            ),
+            Ref::Tag { name, .. } => Some(Span::raw(name).fg(color_theme.list_ref_tag_fg).bold()),
             Ref::Stash { .. } => None,
         })
         .collect();
 
-    let mut spans = vec![Span::raw("(").fg(REF_PAREN_COLOR).bold()];
+    let mut spans = vec![Span::raw("(").fg(color_theme.list_ref_paren_fg).bold()];
 
     if let Head::Detached { target } = head {
         if commit_info.commit.commit_hash == *target {
-            spans.push(Span::raw("HEAD").fg(HEAD_COLOR).bold());
+            spans.push(Span::raw("HEAD").fg(color_theme.list_head_fg).bold());
             if !ref_spans.is_empty() {
-                spans.push(Span::raw(", ").fg(REF_PAREN_COLOR).bold());
+                spans.push(Span::raw(", ").fg(color_theme.list_ref_paren_fg).bold());
             }
         }
     }
@@ -810,16 +812,16 @@ fn refs_spans<'a>(commit_info: &'a CommitInfo, head: &'a Head) -> Vec<Span<'a>>
     for (i, s) in ref_spans.into_iter().enumerate() {
         if let Head::Branch { name } = head {
             if s.content == std::borrow::Cow::Borrowed(name) {
-                spans.push(Span::raw("HEAD -> ").fg(HEAD_COLOR).bold());
+                spans.push(Span::raw("HEAD -> ").fg(color_theme.list_head_fg).bold());
             }
         }
         spans.push(s);
         if i < refs.len() - 1 {
-            spans.push(Span::raw(", ").fg(REF_PAREN_COLOR).bold());
+            spans.push(Span::raw(", ").fg(color_theme.list_ref_paren_fg).bold());
         }
     }
 
-    spans.push(Span::raw(") ").fg(REF_PAREN_COLOR).bold());
+    spans.push(Span::raw(") ").fg(color_theme.list_ref_paren_fg).bold());
 
     if spans.len() == 2 {
         spans.clear(); // contains only "(" and ")", so clear it
@@ -828,21 +830,23 @@ fn refs_spans<'a>(commit_info: &'a CommitInfo, head: &'a Head) -> Vec<Span<'a>>
     spans
 }
 
-fn highlight_matched_text(
+fn highlighted_spans(
     s: String,
-    start: usize,
-    end: usize,
-    base_color: Color,
+    pos: SearchMatchPosition,
+    base_fg: Color,
+    color_theme: &ColorTheme,
+    truncate: bool,
 ) -> Vec<Span<'static>> {
-    let mut chars = s.chars();
-    let head = chars.by_ref().take(start).collect::<String>();
-    let matched = chars.by_ref().take(end - start).collect::<String>();
-    let tail = chars.collect::<String>();
-    vec![
-        head.fg(base_color),
-        matched
-            .fg(MATCH_FOREGROUND_COLOR)
-            .bg(MATCH_BACKGROUND_COLOR),
-        tail.fg(base_color),
-    ]
+    let mut hm = highlight_matched_text(s)
+        .matched_range(pos.start, pos.end)
+        .not_matched_style(Style::default().fg(base_fg))
+        .matched_style(
+            Style::default()
+                .fg(color_theme.list_match_fg)
+                .bg(color_theme.list_match_bg),
+        );
+    if truncate {
+        hm = hm.ellipsis(ELLIPSIS);
+    }
+    hm.into_spans()
 }
